.. index file for release notes pages

=============
Release Notes
=============

The following pages summarize what is new in Avocado:

Regular Releases
================

The regular releases are released after each sprint, which usually takes
3 weeks. Regular releases are supported only until the next version is
released.

.. toctree::
   :maxdepth: 1

   69_0
   68_0
   67_0
   66_0
   65_0
   64_0
   63_0
   62_0
   61_0
   60_0
   59_0
   58_0
   57_0
   56_0
   55_0
   54_1
   54_0
   53_0
   52_0
   51_0
   50_0
   49_0
   48_0
   47_0
   46_0
   45_0
   44_0
   43_0
   42_0
   41_0
   40_0
   39_0
   38_0
   37_0
   36_0
   35_0
   0_34_0
   0_33_0
   0_32_0
   0_31_0
   0_30_0
   0_29_0
   0_28_0
   0_27_1
   0_27_0
   0_26_0
   0_25_0

Long Term Stability Releases
============================

The LTS releases are regular releases considering the release cycle, but
a new branch is created and bugfixes are backported on demand for a
period of about 18 months after the release. Every year (or so) a new
LTS version is released. Two subsequent LTS versions are guaranteed to
have 6 months of supportability overlap.

.. toctree::
   :maxdepth: 1

   lts/69_3
   lts/69_2
   lts/69_1
   lts/69_0
   lts/52_0
   lts/next
